@@ -1,13 +1,12 @@
 package Games::LMSolve::Base;
+our $AUTHORITY = 'cpan:SHLOMIF';
 
 use strict;
 use warnings;
 
 use Getopt::Long;
 
-use vars qw($VERSION);
-
-$VERSION = '0.8.6';
+our $VERSION = '0.8.6';
 
 use Exporter;
 
@@ -31,56 +30,6 @@ use vars qw(%cell_dirs);
         'W' => [-1,0],
     );
 
-=head1 NAME
-
-Games::LMSolve::Base - base class for puzzle solvers.
-
-=head1 SYNOPSIS
-
-    package MyPuzzle::Solver;
-
-    use Games::LMSolve::Base;
-
-    @ISA = qw(Games::LMSolve::Base);
-
-    # Override these methods:
-
-    sub input_board { ... }
-    sub pack_state { ... }
-    sub unpack_state { ... }
-    sub display_state { ... }
-    sub check_if_final_state { ... }
-    sub enumerate_moves { ... }
-    sub perform_move { ... }
-
-    # Optionally:
-    sub render_move { ... }
-    sub check_if_unsolvable { ... }
-
-    package main;
-
-    my $self = MyPuzzle::Solver->new();
-
-    $self->solve_board($filename);
-
-=head1 DESCRIPTION
-
-This class implements a generic solver for single player games. In order
-to use it, one must inherit from it and implement some abstract methods.
-Afterwards, its interface functions can be invoked to actually solve
-the game.
-
-=head1 METHODS
-
-=head2 new()
-
-The constructor.
-
-=head2 $self->initialize()
-
-Should be inherited to implement the construction.
-
-=cut
 
 sub new
 {
@@ -107,11 +56,6 @@ sub initialize
     return 0;
 }
 
-=head2 $self->main()
-
-Actually solve the board based on the arguments in the command line.
-
-=cut
 
 my %scan_functions =
 (
@@ -166,9 +110,6 @@ sub main
 }
 
 
-=head1 METHODS TO OVERRIDE
-
-=cut
 
 
 
@@ -181,33 +122,12 @@ sub _die_on_abstract_function
         "called, while it needs to be overrided by the derived class.\n");
 }
 
-=head2 input_board($self, $file_spec)
-
-This method is responsible to read the "board" (the permanent parameters) of
-the puzzle and its initial state. It should place the board in the object's
-keys, and return the initial state. (in unpacked format).
-
-Note that $file_spec can be either a filename (if it's a string) or a reference
-to a filehandle, or a reference to the text of the board. input_board() should
-handle all cases.
-
-You can look at the Games::LMSolve::Input module for methods that facilitate
-inputting a board.
-
-=cut
 
 sub input_board
 {
     return _die_on_abstract_function();
 }
 
-=head2 pack_state($self, $state_vector)
-
-This function accepts a state in unpacked form and should return it in packed
-format. A state in unpacked form can be any perl scalar (as complex as you
-like). A state in packed form must be a string.
-
-=cut
 
 # A function that accepts the expanded state (as an array ref)
 # and returns an atom that represents it.
@@ -216,12 +136,6 @@ sub pack_state
     return _die_on_abstract_function();
 }
 
-=head2 unpack_state($self, $packed_state)
-
-This function accepts a state in a packed form and should return it in its
-expanded form.
-
-=cut
 
 # A function that accepts an atom that represents a state
 # and returns an array ref that represents it.
@@ -230,12 +144,6 @@ sub unpack_state
     return _die_on_abstract_function();
 }
 
-=head2 display_state($self, $packed_state)
-
-Accepts a packed state and should return the user-readable string
-representation of the state.
-
-=cut
 
 # Accept an atom that represents a state and output a
 # user-readable string that describes it.
@@ -244,24 +152,12 @@ sub display_state
     return _die_on_abstract_function();
 }
 
-=head2 check_if_final_state($self, $state_vector)
-
-This function should return 1 if the expanded state $state_vector is
-a final state, and the game is over.
-
-=cut
 
 sub check_if_final_state
 {
     return _die_on_abstract_function();
 }
 
-=head2 enumerate_moves($self, $state_vector)
-
-This function accepts an expanded state and should return an array of moves
-that can be performed on this state.
-
-=cut
 
 # This function enumerates the moves accessible to the state.
 # If it returns a move, it still does not mean that this move is a valid
@@ -271,14 +167,6 @@ sub enumerate_moves
     return _die_on_abstract_function();
 }
 
-=head2 perform_move($self, $state_vector, $move)
-
-This method accepts an expanded state and a move. It should try to peform
-the move on the state. If it is successful, it should return the new
-state. Else, it should return undef, to indicate that the move cannot
-be performed.
-
-=cut
 
 # This function accepts a state and a move. It tries to perform the
 # move on the state. If it is succesful, it returns the new state.
@@ -289,12 +177,6 @@ sub perform_move
     return _die_on_abstract_function();
 }
 
-=head2 check_if_unsolvable($self, $state_vector) (optional over-riding)
-
-This method returns the verdict if C<$state_vector> cannot be solved. This
-method defaults to returning 0, and it is usually safe to keep it that way.
-
-=cut
 
 # This function checks if a state it receives as an argument is a
 # dead-end one.
@@ -303,12 +185,6 @@ sub check_if_unsolvable
     return 0;
 }
 
-=head2 render_move($self, $move) (optional overriding)
-
-This function returns the user-readable stringified represtantion of a
-move.
-
-=cut
 
 # This is a function that should be overrided in case
 # rendering the move into a string is non-trivial.
@@ -321,9 +197,6 @@ sub render_move
     return defined($move)?$move:"";
 }
 
-=head1 API
-
-=cut
 
 sub _solve_brfs_or_dfs
 {
@@ -465,15 +338,6 @@ sub _solve_state
         );
 }
 
-=head2 $self->solve_board($file_spec, %args)
-
-Solves the board specification specified in $file_spec. %args specifies
-optional arguments. Currently there is one: 'max_iters' that specifies the
-maximal iterations to run.
-
-Returns whatever run_scan returns.
-
-=cut
 sub solve_board
 {
     my $self = shift;
@@ -485,21 +349,6 @@ sub solve_board
     return $self->_solve_state($initial_coords, @_);
 }
 
-=head2 $self->run_scan(%args)
-
-Continues the current scan. %args may contain the 'max_iters' parameter
-to specify a maximal iterations limit.
-
-Returns two values. The first is a progress indicator. "solved" means the
-puzzle was solved. "unsolved" means that all the states were covered and
-the puzzle was proven to be unsolvable. "interrupted" means that the
-scan was interrupted in the middle, and could be proved to be either
-solvable or unsolvable.
-
-The second argument is the final state and is valid only if the progress
-value is "solved".
-
-=cut
 
 sub run_scan
 {
@@ -514,11 +363,6 @@ sub run_scan
         );
 }
 
-=head2 $self->get_num_iters()
-
-Retrieves the current number of iterations.
-
-=cut
 
 sub get_num_iters
 {
@@ -527,12 +371,6 @@ sub get_num_iters
     return $self->{'num_iters'};
 }
 
-=head2 $self->display_solution($progress_code, $final_state)
-
-If you input this message with the return value of run_scan() you'll get
-a nice output of the moves to stdout.
-
-=cut
 
 sub display_solution
 {
@@ -606,18 +444,6 @@ sub _default_rtd_callback
     print ((" " x $args{depth}) . join(",", @{$args{state}}) . " M=" . $self->render_move($args{move}) ."\n");
 }
 
-=head2 $self->set_run_time_states_display(\&states_display_callback)
-
-Sets the run time states display callback to \&states_display_callback.
-
-This display callback accepts a reference to the solver and also the following
-arguments in key => value pairs:
-
-"state" - the expanded state.
-"depth" - the depth of the state.
-"move" - the move leading to this state from its parent.
-
-=cut
 
 sub set_run_time_states_display
 {
@@ -637,6 +463,176 @@ sub set_run_time_states_display
     return 0;
 }
 
+
+1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Games::LMSolve::Base - base class for puzzle solvers.
+
+=head1 VERSION
+
+version 0.10.0
+
+=head1 SYNOPSIS
+
+    package MyPuzzle::Solver;
+
+    use Games::LMSolve::Base;
+
+    @ISA = qw(Games::LMSolve::Base);
+
+    # Override these methods:
+
+    sub input_board { ... }
+    sub pack_state { ... }
+    sub unpack_state { ... }
+    sub display_state { ... }
+    sub check_if_final_state { ... }
+    sub enumerate_moves { ... }
+    sub perform_move { ... }
+
+    # Optionally:
+    sub render_move { ... }
+    sub check_if_unsolvable { ... }
+
+    package main;
+
+    my $self = MyPuzzle::Solver->new();
+
+    $self->solve_board($filename);
+
+=head1 DESCRIPTION
+
+This class implements a generic solver for single player games. In order
+to use it, one must inherit from it and implement some abstract methods.
+Afterwards, its interface functions can be invoked to actually solve
+the game.
+
+=head1 VERSION
+
+version 0.10.0
+
+=head1 METHODS
+
+=head2 new()
+
+The constructor.
+
+=head2 $self->initialize()
+
+Should be inherited to implement the construction.
+
+=head2 $self->main()
+
+Actually solve the board based on the arguments in the command line.
+
+=head1 METHODS TO OVERRIDE
+
+=head2 input_board($self, $file_spec)
+
+This method is responsible to read the "board" (the permanent parameters) of
+the puzzle and its initial state. It should place the board in the object's
+keys, and return the initial state. (in unpacked format).
+
+Note that $file_spec can be either a filename (if it's a string) or a reference
+to a filehandle, or a reference to the text of the board. input_board() should
+handle all cases.
+
+You can look at the Games::LMSolve::Input module for methods that facilitate
+inputting a board.
+
+=head2 pack_state($self, $state_vector)
+
+This function accepts a state in unpacked form and should return it in packed
+format. A state in unpacked form can be any perl scalar (as complex as you
+like). A state in packed form must be a string.
+
+=head2 unpack_state($self, $packed_state)
+
+This function accepts a state in a packed form and should return it in its
+expanded form.
+
+=head2 display_state($self, $packed_state)
+
+Accepts a packed state and should return the user-readable string
+representation of the state.
+
+=head2 check_if_final_state($self, $state_vector)
+
+This function should return 1 if the expanded state $state_vector is
+a final state, and the game is over.
+
+=head2 enumerate_moves($self, $state_vector)
+
+This function accepts an expanded state and should return an array of moves
+that can be performed on this state.
+
+=head2 perform_move($self, $state_vector, $move)
+
+This method accepts an expanded state and a move. It should try to peform
+the move on the state. If it is successful, it should return the new
+state. Else, it should return undef, to indicate that the move cannot
+be performed.
+
+=head2 check_if_unsolvable($self, $state_vector) (optional over-riding)
+
+This method returns the verdict if C<$state_vector> cannot be solved. This
+method defaults to returning 0, and it is usually safe to keep it that way.
+
+=head2 render_move($self, $move) (optional overriding)
+
+This function returns the user-readable stringified represtantion of a
+move.
+
+=head1 API
+
+=head2 $self->solve_board($file_spec, %args)
+
+Solves the board specification specified in $file_spec. %args specifies
+optional arguments. Currently there is one: 'max_iters' that specifies the
+maximal iterations to run.
+
+Returns whatever run_scan returns.
+
+=head2 $self->run_scan(%args)
+
+Continues the current scan. %args may contain the 'max_iters' parameter
+to specify a maximal iterations limit.
+
+Returns two values. The first is a progress indicator. "solved" means the
+puzzle was solved. "unsolved" means that all the states were covered and
+the puzzle was proven to be unsolvable. "interrupted" means that the
+scan was interrupted in the middle, and could be proved to be either
+solvable or unsolvable.
+
+The second argument is the final state and is valid only if the progress
+value is "solved".
+
+=head2 $self->get_num_iters()
+
+Retrieves the current number of iterations.
+
+=head2 $self->display_solution($progress_code, $final_state)
+
+If you input this message with the return value of run_scan() you'll get
+a nice output of the moves to stdout.
+
+=head2 $self->set_run_time_states_display(\&states_display_callback)
+
+Sets the run time states display callback to \&states_display_callback.
+
+This display callback accepts a reference to the solver and also the following
+arguments in key => value pairs:
+
+"state" - the expanded state.
+"depth" - the depth of the state.
+"move" - the move leading to this state from its parent.
+
 =head1 SEE ALSO
 
 L<Games::LMSolve::Input>
@@ -645,7 +641,141 @@ L<Games::LMSolve::Input>
 
 Shlomi Fish, L<http://www.shlomifish.org/>
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2014 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+http://rt.cpan.org/Public/Dist/Display.html?Name=Games-LMSolve or by email
+to bug-games-lmsolve@rt.cpan.org.
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Perldoc
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc Games::LMSolve
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<http://metacpan.org/release/Games-LMSolve>
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/Games-LMSolve>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Games-LMSolve>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/Games-LMSolve>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/Games-LMSolve>
+
+=item *
+
+CPAN Forum
+
+The CPAN Forum is a web forum for discussing Perl modules.
+
+L<http://cpanforum.com/dist/Games-LMSolve>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.cpanauthors.org/dist/Games-LMSolve>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/G/Games-LMSolve>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=Games-LMSolve>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=Games::LMSolve>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-games-lmsolve at rt.cpan.org>, or through
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Games-LMSolve>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/shlomif/lm-solve-source>
+
+  git clone https://github.com/shlomif/lm-solve-source.git
+
 =cut
-
-1;
-
